<?php

/**

 * Admin Functions

 * @package ABG

 * @subpackage Admin

 */



/**

 * Register the settings

 * @since 1.0

 */

function abg_register_settings() {

	register_setting( ABG_SLUG, 'ABG_default_title' );

	register_setting( ABG_SLUG, 'ABG_alertpay_email' );

	register_setting( ABG_SLUG, 'ABG_thank_you_page' );

	register_setting( ABG_SLUG, 'ABG_cancel_page' );

	register_setting( ABG_SLUG, 'ABG_donate_description' );

	register_setting( ABG_SLUG, 'ABG_buy_now_button' );

	register_setting( ABG_SLUG, 'ABG_subscribe_button' );

	register_setting( ABG_SLUG, 'ABG_donate_button' );

}



/**

 * Sets the help tab on the options page.

 * @since 1.0

 */

function abg_help_text($text) {

	$help_text = '';

	if($_GET['page'] == ABG_SLUG) {

		$help_text .= '<h3>' . ABG_NAME . '</h3>';

		$help_text .= '<p><strong>Default Title</strong></p>';

		$help_text .= '<p>The default name that each product will have.  This can be changed with the shortcode.</p>';

		$help_text .= '<p><strong>Primary AlertPay Email Address</strong></p>';

		$help_text .= '<p>The AlertPay email you want payments sent to.</p>';

		$help_text .= '<p><strong>Thank You Page</strong></p>';

		$help_text .= '<p>What page you want your users to return to once payment is complete.</p>';

		$help_text .= '<p><strong>Cancel Page</strong></p>';

		$help_text .= '<p>What page you want your users to return to if payment is cancelled.</p>';

		$help_text .= '<p><strong>Default Donate Description</strong></p>';

		$help_text .= '<p>The default description for donations if one is not used in the shortcode.</p>';

		$help_text .= '<p><strong>Example Usage</strong></p>';

		$help_text .= '<p><strong><em>Buy Now Button</em></strong></p>';

		$help_text .= '<p>You create a "Buy Now" button by using the following shortcode.  Just define price or you can define a custom product name as well.</p>';

		$help_text .= '<p><code>[ap-buy-now price="9.99"]</code></p>';

		$help_text .= '<p><code>[ap-buy-now email="me@site.com" product="My Cool Plugin" price="9.99"]</code></p>';

		$help_text .= '<p>You can include your own button image (this is common to all button types):</p>';

		$help_text .= '<p><code>[ap-buy-now button_image="http://www.mydomain.com/my_button_image.gif"]</code></p>';

		$help_text .= '<p><strong><em>Subscription</em></strong></p>';

		$help_text .= '<p>You create a subscription button the same way you create a buy-now button. Only here you need to define two types of payments: the initial payment and the recurring payments.</p>';

		$help_text .= '<p><code>[ap-subscribea product="My Cool Widget" price="9.99" prices="9.99"]</code></p>';

		$help_text .= '<p>Other parameters include: p1type (initial) and p3type (recurring) = Day/Week/Month/Year</p>';
		$help_text .= '<p>period1 (initial) and period3 (recurring) = length of period in the above unit types.</p>';
		$help_text .= '<p><code>[ap-subscribea product="My Cool Widget" price="0" prices="9.99" p1type="Day" period1="7" p3type="Month" period3="1"]</code></p>';

		$help_text .= '<p><strong><em>Donate</em></strong></p>';

		$help_text .= '<p>You can just use the default shortcode or you can define a custom description and/or price for each button.</p>';

		$help_text .= '<p><code>[ap-donate]</code></p>';

		$help_text .= '<p><code>[ap-donate description="Please Donate To My Cause!" price="5.00"]</code></p>';

	}

	$help_text .= $text;

	return $help_text;

}



/**

 * donate link in options page

 * @since 1.0

 */

function abg_admin_donate() {

	if(ABG_DONATE_LINK) {

		$img_folder = '../' . PLUGINDIR . '/' . ABG_SLUG . '/lib/img/donate-01.gif';

		$donate_email = ABG_DONATE_EMAIL;

		$donate_name = ABG_NAME;

		$donate = <<<DONATE

	<form action="https://www.alertpay.com/PayProcess.aspx" method="post" target="_blank">

<input type="hidden" name="ap_merchant" value="$donate_email">

<input type="hidden" name="ap_purchasetype" value="item">

<input type="hidden" name="ap_itemname" value="$donate_name Support">

<input type="text" name="ap_amount" value="1.00">

<input type="hidden" name="ap_currency" value="USD">

<input type="image" src="$img_folder" border="0" name="submit" alt="AlertPay - My Way To Pay">

</form>




DONATE;

	echo $donate;

	}

}





/**

 * Creates the Buy Now Button Drop Down

 * @since 1.0

 */

function abg_button_dropdown($selected, $name, $buttons) {

	

	$select = '<select id="'.$name.'" name="'.$name.'">';

		foreach($buttons as $key=>$value) {

			$select .= '<option value="'.$key.'">'.$value.'</option>';

		}

	$select .= '</select>';

	

	return str_ireplace('option value="'.$selected.'">', 'option value="'.$selected.'" SELECTED>', $select);

}





/**

 * Enqueues the Admin Javascript libraries

 * @since 1.0

 */

function abg_admin_javascript() {

	if($_GET['page'] == AGB_SLUG) {

		wp_enqueue_script('jquery');

	}

}





/**

 * Custom Javascript For Options Page

 * @since 1.0

 */

function abg_admin_footer_javascript() {

	if($_GET['page'] == ABG_SLUG) {

		$img_folder = '../' . PLUGINDIR . '/' . ABG_SLUG . '/lib/img/';

		$js = <<<JS

		<script type="text/javascript">

		jQuery(document).ready(function($) {

			

			// changes the buy now button image

			$("#ABG_buy_now_button").change(function() {

        		var src = $("option:selected", this).val();

        		$("#ABG_buy_now_button_preview").html(src ? "<img src='$img_folder" + src + ".gif'>" : "");

    		});

    		

    		// changes the susbcribe button image

			$("#ABG_subscribe_button").change(function() {

        		var src = $("option:selected", this).val();

        		$("#ABG_subscribe_button_preview").html(src ? "<img src='$img_folder" + src + ".gif'>" : "");

    		});

    		
    		

    		// changes the donate button image

			$("#ABG_donate_button").change(function() {

        		var src = $("option:selected", this).val();

        		$("#ABG_donate_button_preview").html(src ? "<img src='$img_folder" + src + ".gif'>" : "");

    		});

    		

		});

		</script>

		

JS;

	echo $js;

	}

}



?>